bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 18. Aventiure
___________________________________________________
###### 1070 | ### <· er> sweher Criemhilde gie da er si vant ### er sprach cer chveneginne wir svln in vnser lant ### wir wæn vnmære geste bi dem Rine sin ### Criemhilt vil liebiv vrowe nv vart ir zv den landen min
###### 1071 | ### Sit daz vns vntriwe ane hat getan ### hi in disen landen des iwern edeln man ### des svlt ir niht engelten ich vil iv wæge sin ### dvrch mines svns liebe des svlt [341a] ir ane zwivel sin
###### 1072 | ### Ir svlt haben vrowe allen den gewalt ### den iv ê tæte chvnde Sifrit der degen balt ### daz lant vnd ovch div chrone daz si iv vndertan ### iv svln gerne dienen alle Sifrides man
###### 1073 | ### Do saget man den chnehten si solden riten dan ### do wart ein michel gahen nach rossen getan ### bi ir starchen vienden was in ze wesin leit ### den vrowen vnt den megden hiez man svchen div chleit
| ### Do der kvnich Sigemvnt wolde sin geriten ### do begonde Criemhilt di ir mage biten ### daz si bi ir mvter solde da bestan ### do sprach div vrowe herre daz chvnde niemer ergan
###### 1075 | ### Wi mohten ich den immer mit ovgen an gesehen ### von dem mir armem wibe so leide ist geschehen ### do sprach der ivnge Giselher vil liebiv swester min ### dv solt dvrch dine triwe hi bi diner mvter sin
###### 1076 | ### Di dich da habent <beswæret> vnde betrvebet den mvt ### der bedarftv niht ce dienste nv zer min eines gvt ### si sprach zv dem rechen iane mages niht geschehen ### vor leide mvoz ich sterben swenne ich Hagenen mvse sehen
| ### Des tvn ich dir ce rate vil liebiv swester min ### dv solt bi dinem brvder Giselhere sin ### ia wil ich dich ergezzen dines mannes tot ### do sprach div gotes arme des wære Criemhilde not
###### 1078 | ### Do wz ir der ivnge Giselher so gvetlich erbot ### do begonde vlêgen Vote vnd Gernot ### vnd ir getriwe mage si baten si da bestan ### si hete lvecel chvennes vnder Sifrides man
###### 1079 | ### Si sint iv alle vremde so sprach Gernot ### ezen lebet so starcher niemen erne mveze ligen tot ### daz bedencht liebiv swester vnd troestet iwern mvt ### belibt bi den vrivnden daz wirt iv wærlichen gvt [341b]
| ### Si lobte Giselhern si wolde da bestan ### div ross gezogen waren den Sigemvndes man ### als si wolden riten cer Nibelvnge lant ### do was ovch vf gesovmet al der recken gewant
###### 1081 | ### Do gie der herre Sigemvnt zv Criemhilde stan ### er sprach zv der vrowen di Sifrides man ### nv warten bi den rossen nv svl wir riten hin ### wand ich vil vngerne bi den Bvergonden bin
###### 1082 | ### Do sprach div vrowe Criemhilt mir ratent di vrivnde min ### swaz ich han getriwen ich svl hie bi in sin ### ich habe niemen mage in Nibelvnge lant ### vil leit was iz Sigemvnde do erz an Criemhilde ervant
| ### Do sprach der kvenich Sigemvnt lat iv niemen sagen ### vor allen minen magen svlt ir di chrone tragen ### also gewaltechliche als ir e habt getan ### ir en svlt des niht engelten daz wir den helt verloren han
###### 1084 | ### Vnd vart ovch mit vns wider dvrch iwer chindelin ### daz en svlt ir niht vrowe weise lazen sin ### swenne iwer svn gewahset der trostet iv den mvt ### di wile sol iv dienen manich helt chvne vnd gvt
###### 1085 | ### Si sprach herre Sigemvnt iane mach ich riten niht ### ich mvz hie beliben swaz halt mir geschit ### bi den minen magen di mir helfen chlagen ### do begonden disiv mære den gvten recken missehagen
| ### Si sprachen al geliche so moehte wir wol iehen ### daz vns allererste wære leit geschehen ### woldet ir beliben bi vnsern vinden hie ### so geritten hovereise noch helde sorchlicher nie
###### 1087 | ### Ir svlt ane sorge got bevolhen varn ### man git iv gvt geleite ich heiz ivch wol bewarn ### zv Sigemvndes lande min liebez chindelin ### daz sol vf genade iv rechen wol bevolhen sin
###### 1088 | ### Do si wol vernamen daz si niht wolde dan ### do weinten al geliche di Sigemvndes [342a] ### wi rehte iamerlichen schiet do Sigemvnt ### von vrovn Criemhilde do was im vngemvete chvnt
###### 1089 | ### So we der hohgecite sprach do der kvnech her ### ez geschit von chvrcewile hinfvr nimmer mer ### kvnige noch sinen magen daz vns ist geschehen ### man sol nimmer mere hi cen Bvergonden sehen
###### 1090 | ### Do sprachen offenliche di Sigemvndes man ### ez mohte noch div reise in diz lant ergan ### so wir den reht erfinden der vns den herren slvch ### si habent von sinen magen starcher viende genvch
| ### Er chvste Criemhilden wi iamerlichn er sprach ### do si beliben wolde vnd er daz reht ersach ### nv riten vrevden ane heim in vnser lant ### alle mine sorge sint mir erste nv bechant
###### 1092 | ### Si riten an geleite von Wormez <nden> Rin ### s mohten wol des mvtes vil sicherlichen sin ### ob si in vientschepfte werden an gerant ### daz sich weren wolde der chvnen Nibelvnge hant
###### 1093 | ### Sine gerten vrlovbes da ze cheinem man ### do sah man Gernot vnd Giselheren gan ### zv zim minnechlichen im was sin schade leit ### des <brahten> in wol inne di helde chvne vnt gemeit
| ### Do sprach gezogenlichen der fvrste Gernot ### got weiz daz wol von himele an Sifrides tot ### gewan ich ni di <schvlde> daz ich daz horte sagen ### wer im hie vient wære ich sol in pilliche chlagen
###### 1095 | ### Do gab in gvt geleite Giselher daz chint ### er brahte sorgende vz dem lande sint ### den kvenich mit sinen recken heim ce Niderlant ### wi lvecel man der mage dar inne vroelichen vant
###### 1096 | ### Wi si nv gefveren des chan ich niht gesagen ### man horte hie zallen ziten Criemhilde chlagen ### daz ir niemen troste daz herce vnt ovch den mvt ### ezen tæte Giselher der was getriwe vnde gvt [342b]
###### 1097 | ### <Prvnhilt> div schoene mit vebermvete saz ### swaz geweinte Criemhilt vnmær was ir daz ### sine wart <ir> gvter triwe <nimmer mer> bereit ### sit getet ir ovch vrov Criemhilt div vil hercenlichen leit

<<< Übersicht <<< vorige Seite nächste Seite >>>